Calculates the Boltzmann entropy of a landscape gradient. This package uses the analytical method created by Gao, P., Zhang, H. and Li, Z., 2018 (tools:::Rd_expr_doi("10.1111/tgis.12315")) and by Gao, P. and Li, Z., 2019 (tools:::Rd_expr_doi("10.1007/s10980-019-00854-3")). It also extend the original ideas by allowing calculations on data with missing values.
Maintainer: Jakub Nowosad nowosad.jakub@gmail.com (ORCID)
Other contributors:
Space Informatics Lab [copyright holder]
Useful links: